<?php # $Id: serendipity_lang_en.inc.php 1252 2006-06-09 20:17:14Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-2');
@define('SQL_CHARSET', 'utf8');
@define('DATE_LOCALES', 'pl-UTF-8, pl-UTF8, pl_PL-UTF-8, pl_PL-UTF8, pl.UTF8, pl_PL.UTF8, polish, pl, pl_PL');
@define('DATE_FORMAT_ENTRY', '%A, %B %e. %Y');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'en');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Panel Administracyjny Serendipity');
@define('HAVE_TO_BE_LOGGED_ON', 'Musisz si wpierw zalogowa by mc obejrze t stron');
@define('WRONG_USERNAME_OR_PASSWORD', 'Wprowadzono bdn nazw uytkownika lub haso.');
@define('APPEARANCE', 'Wygld');
@define('MANAGE_STYLES', 'Zarzdzanie stylami');
@define('CONFIGURE_PLUGINS', 'Konfiguracja wtyczek');
@define('CONFIGURATION', 'Konfiguracja');
@define('BACK_TO_BLOG', 'Powrt do bloga');
@define('LOGIN', 'Login');
@define('LOGOUT', 'Logout');
@define('LOGGEDOUT', 'Wylogowany(a).');
@define('CREATE', 'Stwrz');
@define('SAVE', 'Zapis');
@define('NAME', 'Nazwa');
@define('CREATE_NEW_CAT', 'Nowa kategoria');
@define('I_WANT_THUMB', 'Chc uy miniaturki we wpisie');
@define('I_WANT_BIG_IMAGE', 'Chc uy obrazka w penym rozmiarze we wpisie');
@define('I_WANT_NO_LINK', 'Obrazek ma byc wywietlany jako zwyky obrazek');
@define('I_WANT_IT_TO_LINK', 'Obrazek ma by wywietlany jako link do:');
@define('BACK', 'Wstecz');
@define('FORWARD', 'Dalej');
@define('ANONYMOUS', 'Anonymous');
@define('NEW_TRACKBACK_TO', 'Nowy lad (trackback) do');
@define('NEW_COMMENT_TO', 'Nowy komentarz do');
@define('RECENT', 'Ostatnie....');
@define('OLDER', 'Starsze...');
@define('DONE', 'Zrobione');
@define('WELCOME_BACK', 'Witaj,');
@define('TITLE', 'Tytu');
@define('DESCRIPTION', 'Opis');
@define('PLACEMENT', 'Strona');
@define('DELETE', 'Usu');
@define('SAVE', 'Zapis');
@define('UP', 'Gra');
@define('DOWN', 'D');
@define('ENTRIES', 'wpisy');
@define('NEW_ENTRY', 'Nowy wpis');
@define('EDIT_ENTRIES', 'Edycja wpisw');
@define('CATEGORIES', 'Kategorie');
@define('WARNING_THIS_BLAHBLAH', "UWAGA:\\nTo moe nieco potrwa jeli jest wiele obrazkw bez miniaturek.");
@define('CREATE_THUMBS', 'Przebuduj miniatury');
@define('MANAGE_IMAGES', 'Zarzdzanie obrazkami');
@define('NAME', 'Imi');
@define('EMAIL', 'Email');
@define('HOMEPAGE', 'Strona');
@define('COMMENT', 'Komentarz');
@define('REMEMBER_INFO', 'Zapamita dane?');
@define('SUBMIT_COMMENT', 'Wylij komentarz');
@define('NO_ENTRIES_TO_PRINT', 'Brak wpisw do wywietlenia');
@define('COMMENTS', 'Komentarze');
@define('ADD_COMMENT', 'Dodaj komentarz');
@define('NO_COMMENTS', 'Brak komentarzy');
@define('POSTED_BY', 'Zamieci');
@define('ON', 'o');
@define('A_NEW_COMMENT_BLAHBLAH', 'Nowy komentarz na blogu "%s" zosta dodany do wpisu "%s."');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Nowy lad (Trackback) zosta pozostawiony we wpisie "%s".');
@define('NO_CATEGORY', 'Brak kategorii');
@define('ENTRY_BODY', 'Tre wpisu');
@define('EXTENDED_BODY', 'Rozszerzona tre wpisu');
@define('CATEGORY', 'Kategoria');
@define('EDIT', 'Edycja');
@define('NO_ENTRIES_BLAHBLAH', 'Nie znaleziono wpisw zawierajcych zapytanie %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Twoje zapytanie o %s zwrcio %s wynikw:');
@define('SEARCH_TOO_SHORT', 'Ilo znakw w zapytaniu musi by wiksza od trzech. Moesz prbowa doda * do krtszych sw, np. s9y* aby "oszuka" wyszukiwark by uya krtsze zapytania.');
@define('IMAGE', 'Obrazek');
@define('ERROR_FILE_NOT_EXISTS', 'Bd: Stara nazwa pliku nie istnieje!');
@define('ERROR_FILE_EXISTS', 'Bd: Nowa nazwa pliku jest ju w uyciu, wybierz inn!');
@define('ERROR_SOMETHING', 'Bd: Co jest nie tak.');
@define('ADDING_IMAGE', 'Dodawanie obrazka...');
@define('THUMB_CREATED_DONE', 'Miniaturka stworzona.<br/>Zrobione.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Bd: Plik znajduje si ju na Twoim serwerze!');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Wystpi nieznany bd, plik nie zosta zaadowany. By moe konfiguracja serwera nie zezwala na przesyanie tak duych plikw. Sprawd to u swojego ISP lub wyedytuj odpowiednio plik php.ini (jeli masz dostp do konfiguracji serwera) by zezwoli na przesyanie wikszych plikw.');
@define('GO', 'Start!');
@define('NEWSIZE', 'Nowy rozmiar: ');
@define('RESIZE_BLAHBLAH', '<b>Zmie rozmiar: %s</b><p>');
@define('ORIGINAL_SIZE', 'Oryginalny rozmiar: <i>%sx%s</i> pikseli');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Tu moesz zmieni rozmiar obrazka. Jeli chcesz zmieni rozmiar proporcjonalnie, zaznacz odpowiedni opcj, wpisz warto w jedno z pl i wcinij TAB - nowy rozmiar dla drugiej wartoci zostanie automatycznie obliczony, tak by proporcje obrazka zostay zachowane.</p>');
@define('QUICKJUMP_CALENDAR', 'Kalendarz szybkiego dostpu');
@define('QUICKSEARCH', 'Wyszukaj na stronie');
@define('SEARCH_FOR_ENTRY', 'Szukaj wpisu');
@define('ARCHIVES', 'Archiwa');
@define('BROWSE_ARCHIVES', 'Przegldaj archiwa miesicami');
@define('TOP_REFERRER', 'Top Referrers');
@define('SHOWS_TOP_SITES', 'Pokazuje strony, z ktrych najczciej czono si z Twoim blogiem');
@define('TOP_EXITS', 'Top Exits');
@define('SHOWS_TOP_EXIT', 'Pokazuje ilo wychodzcych z Twojego bloga klikni do innych stron');
@define('SYNDICATION', 'Subskrybcja');
@define('SHOWS_RSS_BLAHBLAH', 'Pokazuje linki subskrybcji kanaw RSS Twojego bloga');
@define('ADVERTISES_BLAHBLAH', 'Zareklamuj Serendipity');
@define('HTML_NUGGET', 'Pole HTML');
@define('HOLDS_A_BLAHBLAH', 'Umoliwia wprowadzenie kodu HTML. Efekt dziaania kodu bdzie wywietlany w Panelu Bocznym');
@define('TITLE_FOR_NUGGET', 'Tytu elementu wywietlany na Panelu Bocznym');
@define('THE_NUGGET', 'Kod HTML!');
@define('SYNDICATE_THIS_BLOG', 'Subskrybcja');
@define('YOU_CHOSE', 'Wybrano %s');
@define('IMAGE_ROTATE_LEFT', 'Obr obrazek 90 stopni w lewo');
@define('IMAGE_ROTATE_RIGHT', 'Obr obrazek 90 stopni w prawo');
@define('IMAGE_SIZE', 'Rozmiar obrazka');
@define('IMAGE_AS_A_LINK', 'Linkowanie obrazka');
@define('POWERED_BY', 'Powered by');
@define('TRACKBACKS', 'lady');
@define('TRACKBACK', 'lad');
@define('NO_TRACKBACKS', 'Brak ladw');
@define('TOPICS_OF', 'Tytuy z');
@define('VIEW_FULL', 'pene');
@define('VIEW_TOPICS', 'tytuy');
@define('AT', 'o');
@define('SET_AS_TEMPLATE', 'Ustaw jako aktywny styl');
@define('IN', 'w');
@define('EXCERPT', 'Fragment');
@define('TRACKED', 'Przesany');
@define('LINK_TO_ENTRY', 'Link do wpisu');
@define('LINK_TO_REMOTE_ENTRY', 'Link do wpisu zdalnego');
@define('IP_ADDRESS', 'adres IP');
@define('USER', 'Uytkownik');
@define('THUMBNAIL_USING_OWN', 'Uyj obrazka %s jako jego wasnej miniatury bo ju jest w rozmiarach miniatury.');
@define('THUMBNAIL_FAILED_COPY', 'Chciano uy %s jako jego wanej miniatury ale proces kopiowania si nie powid!');
@define('AUTHOR', 'Autor');
@define('LAST_UPDATED', 'Ostatnio zaktualizowany');
@define('TRACKBACK_SPECIFIC', 'Uyj tego linku jeli chcesz stworzy lad (Trackback) do tego wpisu');
@define('DIRECT_LINK', 'Bezporedni link do tego wpisu');
@define('COMMENT_ADDED', 'Twj komentarz zosta dodany');
@define('COMMENT_ADDED_CLICK', 'Kliknij %stutaj by powrci%s do komentarzy oraz %stutaj by zamkn%s to okno.');
@define('COMMENT_NOT_ADDED_CLICK', 'Kliknij %stutaj aby wrci%s do komentarzy albo %stutaj by zamkn%s to okno.');
@define('COMMENTS_DISABLE', 'Nie zezwalaj na komentowanie tego wpisu');
@define('COMMENTS_ENABLE', 'Zezwalaj na komentowanie tego wpisu');
@define('COMMENTS_CLOSED', 'Autor nie zezwoli na komentowanie tego wpisu');
@define('EMPTY_COMMENT', 'Twj komentarz nie zawiera adnych treci. Prosz, %swr%s i sprbuj ponownie.');
@define('ENTRIES_FOR', 'Wpisy z %s');
@define('DOCUMENT_NOT_FOUND', 'Dokument %s nie zosta odnaleziony.');
@define('USERNAME', 'Uytkownik');
@define('PASSWORD', 'Haso');
@define('AUTOMATIC_LOGIN', 'Zapisz dane');
@define('SERENDIPITY_INSTALLATION', 'Instalacja Serendipity');
@define('LEFT', 'Lewy panel');
@define('RIGHT', 'Prawy panel');
@define('HIDDEN', 'Wtyczka ukryta');
@define('REMOVE_TICKED_PLUGINS', 'Usu zaznaczone wtyczki');
@define('SAVE_CHANGES_TO_LAYOUT', 'Zapisz zmiany w layoucie');
@define('COMMENTS_FROM', 'Formularz komentarzy');
@define('ERROR', 'Bd');
@define('ENTRY_SAVED', 'Twj wpis zosta zapisany');
@define('DELETE_SURE', 'Na pewno usun #%s ?');
@define('NOT_REALLY', 'Nie');
@define('DUMP_IT', 'Tak');
@define('RIP_ENTRY', 'Wpis #%s usunity.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Kategoria #%s zostaa usunita. Stare wpisy zostay przeniesione do kategorii #%s.');
@define('CATEGORY_DELETED', 'Kategoria #%s usunita');
@define('INVALID_CATEGORY', 'Nie podano kategorii do usunicia');
@define('CATEGORY_SAVED', 'Zapisano kategori');
@define('SELECT_TEMPLATE', 'Wybierz styl dla swojego bloga');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Wpisy nie zostay prawidowo zapisane w bazie!');
@define('MT_DATA_FILE', 'Movable Type - plik danych');
@define('FORCE', 'Wymu');
@define('CREATE_AUTHOR', 'Stwrz autora \'%s\'.');
@define('CREATE_CATEGORY', 'Stwrz kategori \'%s\'.');
@define('MYSQL_REQUIRED', 'You must have the MySQL extension in order to perform this action.');
@define('COULDNT_CONNECT', 'Could not connect to MySQL database: %s.');
@define('COULDNT_SELECT_DB', 'Could not select database: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Could not select user information: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Could not select category information: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Could not select entry information: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Could not select comment information: %s.');
@define('YES', 'Tak');
@define('NO', 'Nie');
@define('USE_DEFAULT', 'Default');
@define('CHECK_N_SAVE', 'Sprawd i zapisz');
@define('DIRECTORY_WRITE_ERROR', 'Nie mog zapisywa w katalogu %s. Prosz, sprawd prawa dostpu do katalogu.');
@define('DIRECTORY_CREATE_ERROR', 'Katalog nie istnieje i nie moe by utworzony. Prosz stworzy katalog samodzielnie.');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; run <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Nie mog uruchomi %s');
@define('FILE_WRITE_ERROR', 'Nie mog zapisywa do pliku %s.');
@define('FILE_CREATE_YOURSELF', 'Prosz, stwrz plik samodzielnie lub sprawd prawa dostpu.');
@define('COPY_CODE_BELOW', '<br />* Po prostu skopiuj poniszy kod i umie go w %s w Twoim katalogu %s:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Zmie waciciela katalogu ze stron na uytkownika, z uprawnieniami ktrego dziaa apache (np. nobody).');
@define('BROWSER_RELOAD', 'Kiedy wykonasz te czynnoci wcinij przycisk "reload" (odwie) w swojej przegldarce.');
@define('DIAGNOSTIC_ERROR', 'Stwierdzono istnienie pewnych problemw podczas przeprowadzania procedur diagnostycznych. Upewnij si, e podae prawidowe dane:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity nie zostao jeszcze zainstalowane. Prosz, <a href="%s">zainstaluj</a> je teraz.');
@define('INCLUDE_ERROR', 'serendipity error: could not include %s - exiting.');
@define('DATABASE_ERROR', 'serendipity error: unable to connect to database - exiting.');
@define('CREATE_DATABASE', 'Creating default database setup...');
@define('ATTEMPT_WRITE_FILE', 'Prba zapisania pliku %s ...');
@define('WRITTEN_N_SAVED', 'Konfiguracja zapisana');
@define('IMAGE_ALIGNMENT', 'Wyrwnanie obrazka');
@define('ENTER_NEW_NAME', 'Wprowad now nazw dla: ');
@define('RESIZING', 'Zmieniam rozmiar');
@define('RESIZE_DONE', 'Zrobione (ilo obrazkw, ktrym zmieniono rozmiar: %s).');
@define('SYNCING', 'Synchronizacja bazy danych z katalogiem obrazkw');
@define('SYNC_DONE', 'Zrobione (%s obrazkw zsynchronizowanych).');
@define('FILE_NOT_FOUND', 'Nie mona odnalze pliku <b>%s</b>. By moe zosta ju usunity?');
@define('ABORT_NOW', 'Przerwij teraz');
@define('REMOTE_FILE_NOT_FOUND', 'Nie odnaleziono pliku na zdalnym serwerze, czy na pewno cieka <b>%s</b> jest poprawna?');
@define('FILE_FETCHED', '%s pobrano jako %s');
@define('FILE_UPLOADED', 'Plik %s prawidowo zaadowany na serwer jako %s');
@define('WORD_OR', 'lub');
@define('SCALING_IMAGE', 'Skaluj %s do %s x %s px');
@define('KEEP_PROPORTIONS', 'Zachowaj proporcje');
@define('REALLY_SCALE_IMAGE', 'Na pewno przeskalowa obrazek? Ta operacja jest nieodwracalna!');
@define('TOGGLE_ALL', 'Rozwi/zwi wszystkie');
@define('TOGGLE_OPTION', 'Przecz opcj');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Wylij mailem powiadomienie o odpowiedziach');
@define('UNSUBSCRIBE_OK', "%s subskrypcja tego wpisu zostaa usunita");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Nowy komentarz do subskrybowanej wiadomoci "%s"');
@define('SUBSCRIPTION_MAIL', "Witam %s,\n\nNowy komentarz zosta dodany do wpisu, ktry monitorujesz na \"%s\", zatytuowany \"%s\"\nImi komentujcego to: %s\n\nSkomentowany wpis znajdziesz tutaj: %s\n\nMoesz wyczy powiadomienia o odpowiedziach do tego wpisu klikajc na link: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Witam %s,\n\nNowy lad zosta pozostawiony we wpisie, ktry monitorujesz na \"%s\", zatytuowany \"%s\"\nImi komentujcego to: %s\n\nSkomentowany wpis znajdziesz tutaj: %s\n\nMoesz wyczy powiadomienia o odpowiedziach do tego wpisu klikajc na link: %s\n");
@define('SIGNATURE', "\n-- \n%s jest napdzane przez Serendipity.\nNajlepszy engine blogowy pod tym socem. Ty take moesz go uywa.\nSprawd <http://s9y.org> by si dowiedzie jak!");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 Komentarze');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Pole "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Pole "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Obrazek dla feedw RSS');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Szeroko obrazka');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Wysoko obrazka');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'Adresy e-mail webmastera, o ile dostpne. (puste: ukryte) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'Adresy e-mail edytora zarzdzajcego treci, o ile dostpne. (puste: ukryte) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL do obrazka w formacie GIF/JPEG/PNG, o ile dostpny. (pusty: logo Serendipity)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'w pikselach, max 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'w pikselach, max 400');
@define('SYNDICATION_PLUGIN_TTL', 'Pole "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Ilo minut, po ktrych Twj blog nie powinien by cachowany przez zewntrzne strony/programy obsugujce RSS. (puste: ukryte) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Pole "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Czy pole "pubDate" ma by zaczone w treci RSS? Zawiera ono dat publikacji ostatniego wpisu.');
@define('CONTENT', 'Zawarto');
@define('TYPE', 'Typ');
@define('DRAFT', 'Szkic');
@define('PUBLISH', 'Publikacja');
@define('PREVIEW', 'Podgld');
@define('DATE', 'Data');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Uwaga: data, ktr podano, nie jest prawidowa. Data musi by podana w formacie YYYY-MM-DD HH:MM (RRRR-MM-DD GG:MM).');
@define('CATEGORY_PLUGIN_DESC', 'Pokazuje list kategorii');
@define('ALL_AUTHORS', 'Wszyscy autorzy');
@define('CATEGORIES_TO_FETCH', 'Kategorie do pokazania');
@define('CATEGORIES_TO_FETCH_DESC', 'Poka kategorie zdefiniowane przez ktrego autora?');
@define('PAGE_BROWSE_ENTRIES', 'Strona %s z %s, cznie %s wpisw');
@define('PREVIOUS_PAGE', 'poprzednia strona');
@define('NEXT_PAGE', 'nastpna strona');
@define('ALL_CATEGORIES', 'Wszystkie kategorie');
@define('DO_MARKUP', 'Formatuj za pomoc wtyczek Znacznikw');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Format daty');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Format daty wpisu, uywa zmiennych funkcji strftime() jzyka PHP. (Standardowo: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Nie mog otworzy pliku stylu (template). Prosz, sprawd lub unowoczenij swoj instalacj Serendipity!');
@define('ADVANCED_OPTIONS', 'Zaawansowane ustawienia');
@define('EDIT_ENTRY', 'Edycja wpisu');
@define('HTACCESS_ERROR', 'Aby sprawdzi konfiguracj serwera, na ktrym instalowane jest Serendipity, program musi mie moliwo stworzenia pliku ".htaccess". Nie byo to moliwe ze wzgldu na problemy z uprawnieniami. Prosz, sprawd uprawnienia w taki mniej wicej sposb: <br />&nbsp;&nbsp;%s<br />i przeaduj stron.');
@define('SIDEBAR_PLUGINS', 'Wtyczki Paneli Bocznych');
@define('EVENT_PLUGINS', 'Wtyczki Zdarze');
@define('SORT_ORDER', 'Porzdek sortowania');
@define('SORT_ORDER_NAME', 'Nazwa pliku');
@define('SORT_ORDER_EXTENSION', 'Rozszerzenie pliku');
@define('SORT_ORDER_SIZE', 'Rozmiar pliku');
@define('SORT_ORDER_WIDTH', 'Szeroko obrazka');
@define('SORT_ORDER_HEIGHT', 'Wysoko obrazka');
@define('SORT_ORDER_DATE', 'Data uploadu');
@define('SORT_ORDER_ASC', 'Rosnco');
@define('SORT_ORDER_DESC', 'Malejco');
@define('THUMBNAIL_SHORT', 'Miniatura');
@define('ORIGINAL_SHORT', 'Orygina');
@define('APPLY_MARKUP_TO', 'Zastosuj znacznik do %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Pocztek tygodnia');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity wykryo instalacj wersji %s. Wyglda na to, e prbujesz uaktualni program do wersji %s. Musisz <a href="%s">klikn tutaj</a> by kontynuowa proces aktualizacji.');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Witaj w programie aktualizujcym Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Ten program pomoe Ci uaktualni Twoj instalacj Serendipity %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'Widzisz ten komunikat poniewa wanie zainstalowae(a) Serendipity %s ale jeszcze nie uaktualnie(a) swojej bazy danych by spelniaa wymagania tej wersji Serendipity.');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Uaktualnienia bazy danych (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Nastpujce pliki .sql musz by wykonane by mc korzysta w normalny sposb z Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Zadania specjalne zwizane z t wersj');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Nie wykryto zada specjalnych zwizanych z t wersj');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Czy mam wykona powysze zadania?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Nie, wykonam je wasnorcznie');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Tak, wykonaj je');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Wyglda na to, e nie musisz aktualizowa swojej instalacji');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity zostao zaktualizowane');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Zignorowae(a) etap uaktualnienia Serendipity. Prosz, upewnij si, e Twoja baza danych jest prawidowo zainstalowana a zaplanowane zadania zostan uruchomione.');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Twoja instalacja Serendipity zostaa uaktualniona do wersji %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Moesz powrci do swojego bloga klikajc %stutaj%s');
@define('MANAGE_USERS', 'Uytkownicy');
@define('CREATE_NEW_USER', 'Nowy uytkownik');
@define('CREATE_NOT_AUTHORIZED', 'Nie moesz zmiania danych uytkownikw majcych ten sam Poziom co Ty');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Nie moesz tworzy uytkownikw o wyszym Poziomie ni Twj wasny');
@define('CREATED_USER', 'Nowy uytkownik %s zosta utworzony');
@define('MODIFIED_USER', 'Ustawienia uytkownika %s zostay zmienione');
@define('USER_LEVEL', 'Poziom');
@define('DELETE_USER', 'Zamierzasz usun uytkownika #%d %s. Na pewno? To uniemoliwi wywietlanie jakichkolwiek wpisw tego uytkownika na stronie.');
@define('DELETED_USER', 'Uytkownik #%d %s usunity.');
@define('LIMIT_TO_NUMBER', 'Jak wiele elementw ma by pokazanych?');
@define('ENTRIES_PER_PAGE', 'Wpisw na stron');
@define('XML_IMAGE_TO_DISPLAY', 'XML Button');
@define('XML_IMAGE_TO_DISPLAY_DESC','Linki do feedw XML bd pokazywane za pomoc tego obrazka. Pozostaw puste pole dla ustawie domylnych lub wpisz \'none\' aby nie pokazywa obrazka.');

@define('DIRECTORIES_AVAILABLE', 'Na licie dostpnych podkatalogw moesz klikn na dowolnym katalogu by stworzy nowy katalog w tej strukturze.');
@define('ALL_DIRECTORIES', 'wszystkie katalogi');
@define('MANAGE_DIRECTORIES', 'Katalogi');
@define('DIRECTORY_CREATED', 'Katalog <strong>%s</strong> zosta utworzony.');
@define('PARENT_DIRECTORY', 'Nadrzdny katalog');
@define('CONFIRM_DELETE_DIRECTORY', 'Na pewno usun ca zawarto katalogu %s?');
@define('ERROR_NO_DIRECTORY', 'Bd: Katalog %s nie istnieje');
@define('CHECKING_DIRECTORY', 'Sprawdzanie plikw w katalogu %s');
@define('DELETING_FILE', 'Usuwanie plikw %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Nie mona usun katalogu, w ktrym znajduj si pliki. Zaznacz "siowe usuwanie" jeli chcesz take usun pliki w katalogu. Znajdujce si w katalogu pliki:');
@define('DIRECTORY_DELETE_FAILED', 'Usuwanie katalogu %s nie powiodo si. Sprawd prawa dostpu lub zastosuj si do zalece powyszego powiadomienia.');
@define('DIRECTORY_DELETE_SUCCESS', 'Katalog %s usunity.');
@define('SKIPPING_FILE_EXTENSION', 'Pomijanie pliku: brak rozszerzenia w pliku %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Pomijanie pliku: nie mog czyta z %s.');
@define('FOUND_FILE', 'Znaleziono nowy/zmodyfikowany plik: %s.');
@define('ALREADY_SUBCATEGORY', '%s jest ju podkategori kategorii %s.');
@define('PARENT_CATEGORY', 'Kategoria nadrzdna');
@define('IN_REPLY_TO', 'Odpowied');
@define('TOP_LEVEL', 'Wpis');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('PERMISSIONS', 'Uprawnienia');
@define('SETTINGS_SAVED_AT', 'Ustawienia zostay zapisane o %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Ustawienia bazy danych');
@define('INSTALL_CAT_DB_DESC', 'Tu moesz poda wszystkie dane na temat Twojej bazy danych. Serendipity potrzebuje tych informacji by mc funkcjonowac prawidowo.');
@define('INSTALL_DBTYPE', 'Typ bazy danych');
@define('INSTALL_DBTYPE_DESC', 'Typ bazy danych');
@define('INSTALL_DBHOST', 'Host bazy danych');
@define('INSTALL_DBHOST_DESC', 'Nazwa hosta serwera Twojej bazy danych');
@define('INSTALL_DBUSER', 'Uytkownik bazy danych');
@define('INSTALL_DBUSER_DESC', 'Nazwa uytkownika uywana do czenia si z baz danych');
@define('INSTALL_DBPASS', 'Haso bazy danych');
@define('INSTALL_DBPASS_DESC', 'Haso dla uytkownika podanego powyej');
@define('INSTALL_DBNAME', 'Nazwa bazy danych');
@define('INSTALL_DBNAME_DESC', 'Nazwa Twojej bazy danych');
@define('INSTALL_DBPREFIX', 'Prefiks tabel bazy danych');
@define('INSTALL_DBPREFIX_DESC', 'Prefiks dla nazw tabel, np. serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'cieki');
@define('INSTALL_CAT_PATHS_DESC', 'Rne cieki do istotnych katalogw i plikw. Nie zapomnij o poprzedzajcych katalogi slaszach "/"!');
@define('INSTALL_FULLPATH', 'Pena cieka');
@define('INSTALL_FULLPATH_DESC', 'Pena, bezwzgldna cieka do Twojej instalacji Serendipity');
@define('INSTALL_UPLOADPATH', 'cieka uploadu');
@define('INSTALL_UPLOADPATH_DESC', 'Wszystkie uploady (adowane na serwer pliki) bd trafiay tutaj. Podaj wzgldn (relatywn) w stosunku do "Penej cieki" ciek dostpu - zazwyczaj jest to "uploads/"');
@define('INSTALL_RELPATH', 'Wzgldna cieka');
@define('INSTALL_RELPATH_DESC', 'cieka do Serendipity podawana Twojej przegldarce - zazwyczaj jest to "/serendipity/"');
@define('INSTALL_RELTEMPLPATH', 'Wzgldna cieka styli (templates)');
@define('INSTALL_RELTEMPLPATH_DESC', 'cieka do katalogu zawierajcego style (templates) - wzgldna (relatywna) wobec "wzgldnej cieki"');
@define('INSTALL_RELUPLOADPATH', 'Wzgldna cieka uploadu');
@define('INSTALL_RELUPLOADPATH_DESC', 'cieka uploadu podawana przegldarkom - wzgldna (relatywna) wobec "wzgldnej cieki"');
@define('INSTALL_URL', 'URL bloga');
@define('INSTALL_URL_DESC', 'Bazowy URL instalacji Serendipity');
@define('INSTALL_INDEXFILE', 'Plik index');
@define('INSTALL_INDEXFILE_DESC', 'Nazwa pliku index Twojego Serendipity');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', 'Ustawienia gwne');
@define('INSTALL_CAT_SETTINGS_DESC', 'Ustal gwne ustawienia i zachowania Serendipity');
@define('INSTALL_USERNAME', 'Nazwa uytkownika administratora');
@define('INSTALL_USERNAME_DESC', 'Nazwa uytkownika dla logowania administratora');
@define('INSTALL_PASSWORD', 'Haso administratora');
@define('INSTALL_PASSWORD_DESC', 'Haso dla logowania administratora');
@define('INSTALL_EMAIL', 'E-mail administratora');
@define('INSTALL_EMAIL_DESC', 'Adres e-mail administratora bloga');
@define('INSTALL_SENDMAIL', 'Wysya powiadomienia e-mail do administratora?');
@define('INSTALL_SENDMAIL_DESC', 'Czy chcesz oytrzymywa powiadomienia drog mailow o dopisaniu komentarza do wpisu?');
@define('INSTALL_SUBSCRIBE', 'Zezwala uytkownikom na subskrybowanie wpisw?');
@define('INSTALL_SUBSCRIBE_DESC', 'Czy zezwala uytkownikom na subskrybowanie wpisw a dziki temu na otrzymywanie przez nich powiadomie o komentarzach do tego wpisu drog mailow?');
@define('INSTALL_BLOGNAME', 'Nazwa bloga');
@define('INSTALL_BLOGNAME_DESC', 'Tytu Twojego bloga');
@define('INSTALL_BLOGDESC', 'Opis bloga');
@define('INSTALL_BLOGDESC_DESC', 'Opis Twojego bloga');
@define('INSTALL_LANG', 'Jzyk');
@define('INSTALL_LANG_DESC', 'Wybierz jzyk dla swojego bloga');

/* APPEARANCE AND OPTIONS */
@define('INSTALL_CAT_DISPLAY', 'Wygld i Opcje');
@define('INSTALL_CAT_DISPLAY_DESC', 'Skonfiguruj wygld i ustawienia Serendipity');
@define('INSTALL_WYSIWYG', 'Uyj edytora WYSIWYG');
@define('INSTALL_WYSIWYG_DESC', 'Chcesz uy edytora WYSIWYG? (Dziaa w IE5+, czciowo w Mozilli 1.3+)');
@define('INSTALL_XHTML11', 'Wymu kompatybilno z XHTML 1.1');
@define('INSTALL_XHTML11_DESC', 'Czy chcesz wymusi kompatybilno ze standardem XHTML 1.1 (moe powodowa problemy ze starszymi przegldarkami czwartej generacji)');
@define('INSTALL_POPUP', 'Zezwl na uycie wyskakujcych okien');
@define('INSTALL_POPUP_DESC', 'Chcesz uy wyskakujcych okienek dla komentarzy, ladw itp.?');
@define('INSTALL_EMBED', 'Czy Serendipity jest osadzone?');
@define('INSTALL_EMBED_DESC', 'Jeli chcesz osadzi Serendipity na normalnej stronie, ustaw "Tak" aby pozby si wszelkich informacji nagwkowych i pokazywac sam tre wpisw. Moesz dodatkowo skorzysta z opcji "Plik index" aby stworzy osobn klas, w ktrej bd trzymane nagwki Twojej normalnej strony. Wicej informacji zawiera plik README.');
@define('INSTALL_TOP_AS_LINKS', 'Pokazywa Top Exits/Referrers jako linki?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"Nie": Exits i Referrers s pokazywane czystym tekstem. "Tak": Exits i Referrers s pokazywane jako linki do danych adresw sieciowych. "Standardowo": uywa ustawie z Ustawie gwnych - rekomendowane.');
@define('INSTALL_BLOCKREF', 'Zablokowani Referers');
@define('INSTALL_BLOCKREF_DESC', 'Jeli istnieje jaki host, ktrego nie chcesz pokazywa na licie Referers, wpisz go na t list. Wpisy rozdzielaj rednikami ";".');
@define('INSTALL_REWRITE', 'Nadpisywanie URLi');
@define('INSTALL_REWRITE_DESC', 'Wybierz zasady, wedug ktrych bd generowane URLe. Wczenie opcji nadpisywania URLi bdzie tworzyo adne URLe dla wpisw Twojego bloga, dodatkowo lepiej indeksowalne przez wyszukiwarki typu Google. Serwer musi obsugiwa mod_rewrite lub "AllowOverride All" dla katalogu z Serendipity. Standardowym ustawieniem jest ustawienie wykryte przy prba autodetekcji ustawie serwera.');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', 'Ustawienia konwersji obrazkw');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Wpriwad ustawienia dotyczce sposobw obsugi obrazkw przez Serendipity');
@define('INSTALL_IMAGEMAGICK', 'Uyj ImageMagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Czy masz zainstalowany program ImageMagick i chcesz uy go do zmiany rozmiarw obrazkw?');
@define('INSTALL_IMAGEMAGICKPATH', 'cieka do programu konwertujcego');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Pena cieka do i nazwa uywanego przez Ciebie programu obsugujcego ImageMagick');
@define('INSTALL_THUMBSUFFIX', 'Sufiks Miniaturek');
@define('INSTALL_THUMBSUFFIX_DESC', 'Miniaturki bd nazywane wedug nastpujcego formatu: nazwaoryginalna.[sufiks].rozszerzenie');
@define('INSTALL_THUMBWIDTH', 'Szeroko miniaturki');
@define('INSTALL_THUMBWIDTH_DESC', 'Ustal szeroko tworzonych automatycznie miniatur');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Twoje ustawienia osobiste');
@define('USERCONF_CAT_PERSONAL_DESC', 'Zmie swoje ustawienia osobiste');
@define('USERCONF_USERNAME', 'Twoja nazwa uytkownika');
@define('USERCONF_USERNAME_DESC', 'Nazwa, ktrej uywasz przy logowaniu do bloga');
@define('USERCONF_PASSWORD', 'Twoje haso');
@define('USERCONF_PASSWORD_DESC', 'Haso, ktrego chcesz uy przy logowaniu do bloga');
@define('USERCONF_EMAIL', 'Twj adres e-mail');
@define('USERCONF_EMAIL_DESC', 'Twj prywatny adres e-mail');
@define('USERCONF_SENDCOMMENTS', 'Wysya powiadomienia o komentarzach?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Czy chcesz otrzymywa maile z informacj o komentarzach do Twoich wpisw?');
@define('USERCONF_SENDTRACKBACKS', 'Wysya powiadomienia o ladach?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Czy chcesz otrzymywa maile z informacj o pozostawionych ladach (trackbacks) do Twoich wpisw?');
@define('USERCONF_ALLOWPUBLISH', 'Uprawnienia: Publikowanie wpisw?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Czy ten uytkownik jest uprawniony do publikowania wpisw?');
@define('SUCCESS', 'Sukces');
@define('POWERED_BY_SHOW_TEXT', 'Poka "Serendipity" jako tekst');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Pokae "Serendipity Weblog" jako tekst');
@define('POWERED_BY_SHOW_IMAGE', 'Poka "Serendipity" jako logo');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Pokae logo Serendipity (obrazek)');
@define('PLUGIN_ITEM_DISPLAY', 'Gdzie element ma by wywietlany?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Tylko w penym widoku wpisu');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Tylko na stronie gwnej');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Zawsze');
@define('RSS_IMPORT_CATEGORY', 'Uyj tej kategorii dla importowanych wpisw niepasujcych do innych kategorii');

@define('COMMENTS_WILL_BE_MODERATED', 'Komentarze poddawane s moderacji przed opublikowaniem ich na stronie.');
@define('YOU_HAVE_THESE_OPTIONS', 'Masz do wyboru nastpujce opcje:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Uwaga: Ten komentarz wymaga zaakcpetowania przed opublikowaniem go na stronie.');
@define('DELETE_COMMENT', 'Usu komentarz');
@define('APPROVE_COMMENT', 'Zaaprobuj komentarz');
@define('REQUIRES_REVIEW', 'Wymaga sprawdzenia');
@define('COMMENT_APPROVED', 'Komentarz #%s zosta zaaprobowany');
@define('COMMENT_DELETED', 'Komentarz #%s zosta usunity');
@define('COMMENTS_MODERATE', 'Komentarze i lady (trackbacks) dla tego wpisu wymagaj moderacji');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Uwaga: ten lad (Trackback) wymaga aprobaty zanim zostanie wywietlony na stronie.');
@define('DELETE_TRACKBACK', 'Usu lad (Trackback)');
@define('APPROVE_TRACKBACK', 'Zaaprobuj lad (Trackback)');
@define('TRACKBACK_APPROVED', 'lad (Trackback) #%s zosta zaaprobowany');
@define('TRACKBACK_DELETED', 'lad (Trackback) #%s zosta usunity');
@define('VIEW', 'Ogldaj');
@define('COMMENT_ALREADY_APPROVED', 'Wyglda na to, e komentarz #%s zosta ju zaaprobowany');
@define('COMMENT_EDITED', 'Wybrany komentarz zosta wyedytowany');
@define('HIDE', 'Ukryj');
@define('VIEW_EXTENDED_ENTRY', 'Cig dalszy "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Nie klikaj na ten link. Zawiera on URI ze ladem (Trackback) dla tego wpisu. Moesz uy tego URI by wysa pinga lub stworzy lad ze swojego bloga do tego wpisu. Aby skopiowa ten URI kliknij prawym przyciskiem myszy na linku i wybierz opcj "Kopiuj skrt" (lub podobn).');
@define('PLUGIN_SUPERUSER_HTTPS', 'Uyj https dla logowania');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Link ze Stron logowania bdzie obsugiwany przez https. Twj serwer musi to obsugiwa!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Zewntrzne linki maj by klikalne?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"Nie": Zewntrzne linki (Top Exits, Top Referrers, Komentarze) s pokazywane czystym tekstem, bez podlinkowania odpowiadajcyh im adresw (ogranicza to propagacj spamu - ustawienie rekomendowane). "Tak": Zewntrzne linki s pokazywane jako linki (odpowiadajce im adresy s podlinkowane i klikalne). To ustawienie moe by zmienione przez np. konfiguracj jakiej wtyczki!');
@define('PAGE_BROWSE_COMMENTS', 'Strona %s z %s, cznie %s komentarzy');
@define('FILTERS', 'Filtry');
@define('FIND_ENTRIES', 'Znajd wpisy');
@define('FIND_COMMENTS', 'Znajd komentarze');
@define('FIND_MEDIA', 'Znajd media');
@define('FILTER_DIRECTORY', 'Katalog');
@define('SORT_BY', 'Sortuj');
@define('TRACKBACK_COULD_NOT_CONNECT', 'lad nie zosta wysany: nie mog poczy si z %s uywajc portu %d');
@define('MEDIA', 'Media');
@define('MEDIA_LIBRARY', 'Biblioteka mediw');
@define('ADD_MEDIA', 'Dodaj');
@define('ENTER_MEDIA_URL', 'Wprowad URL pliku dostpnego w sieci:');
@define('ENTER_MEDIA_UPLOAD', 'Wybierz plik do uploadu:');
@define('SAVE_FILE_AS', 'Zapisz plik jako:');
@define('STORE_IN_DIRECTORY', 'Zapisz w nastpujcym katalogu: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>Dodaj plik do zbioru mediw:</b><p>Tu moesz uploadowa pliki z mediami lub wskaza jakie pliki dostpne w sieci! Jeli nie masz odpowiedniego obrazka, <a href="http://images.google.com" target="_blank">znajd w serwisie Google</a> obrazki, ktre by moe bd Ci odpowiaday. Rezultaty wyszukiwania s czsto przydatne i zabawne :) Ale uwaaj! Wikszo obrazkw ma zastrzeone prawa autorskie i powiniene (powinna) zapyta si o pozwolenie przed ich uyciem!</p><p><b>Wybierz metod:</b></p><br />');
@define('MEDIA_RENAME', 'Zmien nazw pliku');
@define('IMAGE_RESIZE', 'Zmie rozmiar obrazka');
@define('MEDIA_DELETE', 'Usu ten plik');
@define('FILES_PER_PAGE', 'Plikw na stron');
@define('CLICK_FILE_TO_INSERT', 'Kliknij na pliku, ktry chcesz umieci:');
@define('SELECT_FILE', 'Wybierz plik do umieszczenia');
@define('MEDIA_FULLSIZE', 'Peen rozmiar');
@define('CALENDAR_BOW_DESC', 'Dzie uznany za pocztek tygodnia. Standardowo jest to poniedziaek.');
@define('SUPERUSER', 'Administracja blogiem');
@define('ALLOWS_YOU_BLAHBLAH', 'Umieszcza w Panelu Bocznym link do Panelu Administracyjnego');
@define('CALENDAR', 'Kalendarz');
@define('SUPERUSER_OPEN_ADMIN', 'Strona logowania');
@define('SUPERUSER_OPEN_LOGIN', 'Strona logowania');
@define('INVERT_SELECTIONS', 'Odwr wybr');
@define('COMMENTS_DELETE_CONFIRM', 'Na pewno usun zaznaczone komentarze?');
@define('COMMENT_DELETE_CONFIRM', 'Na pewno usun komentarz #%d, napisany przez %s?');
@define('DELETE_SELECTED_COMMENTS', 'Usu zaznaczone komentarze');
@define('VIEW_COMMENT', 'Zobacz komentarz');
@define('VIEW_ENTRY', 'Zobacz wpis');
@define('DELETE_FILE_FAIL' , 'Usuwanie pliku <b>%s</b> nie powiodo si');
@define('DELETE_THUMBNAIL', 'Usunito minturk o nazwie	<b>%s</b>');
@define('DELETE_FILE', 'Usunito plik o nazwie <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Masz zamiar usunc plik <b>%s</b><br />Jeli w ktrym z wpisw zostao zdefiniowane odwoanie do pliku, plik ten nie bdzie wicej dla tego odwaania dostpny (link nie bdzie dziaa prawidowo).<br />Czy chcesz kontynuowa?<br /><br />');
@define('TRACKBACK_SENDING', 'Wysyanie ladu do URI %s...');
@define('TRACKBACK_SENT', 'Pozostawienie ladu zakoczone sukcesem');
@define('TRACKBACK_FAILED', 'Pozostawienie ladu nie powiodo si: %s');
@define('TRACKBACK_NOT_FOUND', 'Nie odnaleziono URI dla ustanowienia ladu.');
@define('TRACKBACK_URI_MISMATCH', 'Automatycznie wykryte URI dla ladw nie pasuje do zdefiniowanego adresu docelowego.');
@define('TRACKBACK_CHECKING', 'Badanie moliwoci pozostawienia ladu w <u>%s</u> ...');
@define('TRACKBACK_NO_DATA', 'Miejsce docelowe nie podao odpowiednich danych');
@define('TRACKBACK_SIZE', 'Docelowe URI przekroczyo maksymalny rozmiar %s bajtw (prawdopodobnie link do pliku).');
@define('COMMENTS_VIEWMODE_THREADED', 'Wtki');
@define('COMMENTS_VIEWMODE_LINEAR', 'Pasko');
@define('DISPLAY_COMMENTS_AS', 'Wywietl komentarze jako');
@define('COMMENTS_FILTER_SHOW', 'Poka');
@define('COMMENTS_FILTER_ALL', 'Wszystkie');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Tylko zaaprobowane');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Oczekujce na aprobat');
@define('RSS_IMPORT_BODYONLY', 'Zachowaj cay importowany tekst w sekdji "Tre wpisu" i nie dziel na "Rozszerzona tre wpisu".');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Pokazywa take Rozszerzon tre wpisu w feedzie RSS?');
@define('WEEK', 'Tydzie');
@define('WEEKS', 'Tygodnie');
@define('MONTHS', 'Miesice');
@define('DAYS', 'Dni');
@define('ARCHIVE_FREQUENCY', 'Wywietlany czasokres');
@define('ARCHIVE_FREQUENCY_DESC', 'Jednostki czasu, dla ktrych bdzie generowana lista');
@define('ARCHIVE_COUNT', 'Ilo pozycji na licie');
@define('ARCHIVE_COUNT_DESC', 'Ilo miesicy, tygodni lub dni wywietlanych na licie');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Poniej znajduje si lista zainstalowanych wtyczek.');
@define('SIDEBAR_PLUGIN', 'Wtyczk Panelu Bocznego');
@define('EVENT_PLUGIN', 'Wtyczk Zdarzenia');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Kliknij by zainstalowa now %s');
@define('VERSION', 'wersja');
@define('INSTALL', 'Zainstaluj');
@define('ALREADY_INSTALLED', 'Ju zainstalowane');
@define('SELECT_A_PLUGIN_TO_ADD', 'Wybierz wtyczk, ktr chcesz zainstalowa');
@define('INSTALL_OFFSET', 'Przesunicie czasu serwera');
@define('STICKY_POSTINGS', 'Wpisy Przyklejone');
@define('INSTALL_FETCHLIMIT', 'Ilo wpisw wywietlanych na stronie gwnej');
@define('INSTALL_FETCHLIMIT_DESC', 'Podaj ile wpisw ma by jednoczenie wywietlanych na stronie gwnej i nastpnych stronach bloga');
@define('IMPORT_ENTRIES', 'Importuj dane');
@define('EXPORT_ENTRIES', 'Eksportuj dane');
@define('IMPORT_WELCOME', 'Witaj w module importu danych');
@define('IMPORT_WHAT_CAN', 'Moesz tu importowa wpisy z innych systemw blogowych');
@define('IMPORT_SELECT', 'Wybierz system, z ktrego dane chcesz importowa');
@define('IMPORT_PLEASE_ENTER', 'Wpisz odpowiednie dane, o ktrych podanie prosz poniej');
@define('IMPORT_NOW', 'Importuj!');
@define('IMPORT_STARTING', 'Rozpoczynam procedur importu...');
@define('IMPORT_FAILED', 'Import nie powid si');
@define('IMPORT_DONE', 'Import zakoczony sukcesem');
@define('IMPORT_WEBLOG_APP', 'System blogowy');
@define('IMPORT_NOTES', 'Uwagi:');
@define('EXPORT_FEED', 'Wyeksportuj peen feed RSS');
@define('STATUS', 'Status wpisu po imporcie');
@define('IMPORT_GENERIC_RSS', 'Import RSS');
@define('ACTIVATE_AUTODISCOVERY', 'Wylij lady (Trackbacki) do linkw znalezionych we wpisie/wpisach');
@define('WELCOME_TO_ADMIN', 'Witaj w Panelu Administracyjnym Serendipity.');
@define('PLEASE_ENTER_CREDENTIALS', 'Wprowad swj login i haso w polach poniej.');
@define('ADMIN_FOOTER_POWERED_BY', 'Napdzane przez Serendipity %s i PHP %s');
@define('INSTALL_USEGZIP', 'Uyj kompresji gzip');
@define('INSTALL_USEGZIP_DESC', 'Aby przyspieszy wysyanie stron do uytkownika moesz uy kompresji gzip (zakadajc, e przegldarka uytkownika obsuguje kompresj gzip - znakomita wikszo obsuguje). To ustawienie jest rekomendowane.');
@define('INSTALL_SHOWFUTURE', 'Pokazuj przysze wpisy');
@define('INSTALL_SHOWFUTURE_DESC', 'Jeli opcja zostanie wczona, bd pokazywane wszystkie przysze wpisy (wpisy z ustawion dat przysz). Standardowo wpisy te s ukryte do czasu nadejcia czasu ich wywietlenia.');
@define('INSTALL_DBPERSISTENT', 'Uywaj staych pocze z baz danych');
@define('INSTALL_DBPERSISTENT_DESC', 'Zezwl na uywanie staych pocze z baz danych, wicej <a href="http://pl.php.net/manual/pl/features.persistent-connections.php" target="_blank">tutaj</a>. Wczenie tej opcji nie jest zalecane.');
@define('NO_IMAGES_FOUND', 'Nie znaleziono obrazkw');
@define('PERSONAL_SETTINGS', 'Ustawienie osobiste');
@define('REFERER', 'Referer');
@define('NOT_FOUND', 'Nie znaleziono');
@define('WRITABLE', 'Zapisywalny');
@define('NOT_WRITABLE', 'Niezapisywalny');
@define('PROBLEM_DIAGNOSTIC', 'Z powodu problemw, ktre zostay rozpoznane podczas przeprowadzania procedur diagnostycznych, nie moesz kontynuowa instalacji dopki powysze problemy nie zostan usunite.');
@define('SELECT_INSTALLATION_TYPE', 'Wybierz metod instalacji');
@define('WELCOME_TO_INSTALLATION', 'Witaj w Instalacji Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', 'Najpierw przyjrz si Twojej obecnej konfiguracji i sprbuj rozpozna ewentualne problemy z kompatybilnoci');
@define('ERRORS_ARE_DISPLAYED_IN', 'Kolory oznaczaj: %s - bdy, %s - rekomendacje, %s - sukcesy');
@define('RED', 'czerwony');
@define('YELLOW', 'ty');
@define('GREEN', 'zielony');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s raport przed instalacj');
@define('RECOMMENDED', 'Rekomendowane');
@define('ACTUAL', 'Aktualne');
@define('PHPINI_CONFIGURATION', 'konfiguracja php.ini');
@define('PHP_INSTALLATION', 'Instalacja PHP');
@define('THEY_DO', 'istniej');
@define('THEY_DONT', 'nie istniej');
@define('SIMPLE_INSTALLATION', 'Prosta instalacja');
@define('EXPERT_INSTALLATION', 'Instalacja w trybie Eksperta');
@define('COMPLETE_INSTALLATION', 'Pena instalacja');
@define('WONT_INSTALL_DB_AGAIN', 'nie zainstaluje ponownie bazy danych');
@define('CHECK_DATABASE_EXISTS', 'Sprawdzam czy baza danych i tabele ju istniej');
@define('CREATING_PRIMARY_AUTHOR', 'Tworz gwnego autora \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Ustawiam domylny styl (template)');
@define('INSTALLING_DEFAULT_PLUGINS', 'Instaluj domyslne wtyczki');
@define('SERENDIPITY_INSTALLED', 'Instalacja Serendipity zakoczona sukcesem');
@define('VISIT_BLOG_HERE', 'Tutaj odwied swj nowy blog');
@define('THANK_YOU_FOR_CHOOSING', 'Dzikujemy za wybranie Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Wykryto bd podczas instalacji');
@define('OPERATING_SYSTEM', 'System operacyjny');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('TEMPLATE_SET', '\'%s\' - ustawiono jako aktywny styl bloga');
@define('SEARCH_ERROR', 'Funkcja wyszukiwania nie zadziaaa jak powinna. Uwaga dla administratora tego bloga: To moe si zdarzy w przypadku braku kluczy indeksu w Twojej bazie danych. W systemach opartych na MySQL uzytkownik powinien mie uprawnienia do wykonania nastpujcego zapytania: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Bd zwrcony przez baz danych: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'Edycja kategorii "%s"');
@define('CATEGORY_REMAINING', 'Usu t kategori i przesu wpisy do niej do tej pory nalece do kategorii');
@define('CATEGORY_INDEX', 'Poniej znajduje si lista kategorii dostpna dla Twoich wpisw');
@define('NO_CATEGORIES', 'Brak kategorii');
@define('RESET_DATE', 'Ustaw dat');
@define('RESET_DATE_DESC', 'Kliknij tutaj by ustawi aktualn dat i czas dla tego wpisu');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Prawa dostepu mog by ustawione przez uruchomienie shellowej komendy: `<em>%s</em>` na katalogu lub przez uycie klienta FTP');
@define('WARNING_TEMPLATE_DEPRECATED', 'Uwaga: Twj aktualny styl (template) uywa nieobsugiwanej ju metody, doradzamy aktualizacj Serendipity o ile to moliwe');
@define('ENTRY_PUBLISHED_FUTURE', 'Ten wpis nie zosta jeszcze opublikowany.');
@define('ENTRIES_BY', 'Wpisy napisane przez %s');
@define('PREVIOUS', 'Poprzedni');
@define('NEXT', 'Nastpny');
@define('APPROVE', 'Zaaprobuj');
@define('DO_MARKUP_DESCRIPTION', 'Zastosuj formatowania wtyczek Znacznikw do tekstu (emotikonki, skrty znacznikw tworzone przez uycie *, /, _, ...). Wyczenie tej opcji spowoduje zachowanie kodu HTML w tekcie.');
@define('CATEGORY_ALREADY_EXIST', 'Kategoria o nazwie "%s" ju isnieje');
@define('ERROR_FILE_FORBIDDEN', 'Nie moesz uploadowa plikw z aktywn zawartoci');
@define('ADMIN', 'Administracja');
@define('ADMIN_FRONTPAGE', 'Strona startowa');
@define('QUOTE', 'Cytat');
@define('IFRAME_SAVE', 'Serendipity zapisuje teraz Twj wpis, tworzy lady (trackbacki) i przeprowadza ewentualne odwoania XML-RPC. To moe nieco potrwa...');
@define('IFRAME_SAVE_DRAFT', 'Szkic wiadomoci zosta zapisany');
@define('IFRAME_PREVIEW', 'Serendipity tworzy teraz podgld Twojego wpisu...');
@define('IFRAME_WARNING', 'Twoja przegldarka nie wspiera iframes. Prosz, otwrz plik serendipity_config.inc.php i ustaw zmienn $serendipity[\'use_iframe\'] na FALSE.');
@define('NONE', 'adne');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Standardowe ustawienia dla nowych wpisw');
@define('UPGRADE', 'Uaktualnienie');
@define('UPGRADE_TO_VERSION', 'uaktualnienie do wersji %s');
@define('DELETE_DIRECTORY', 'Usu katalog');
@define('DELETE_DIRECTORY_DESC', 'Zamierzasz usun zawarto katalogu, w ktrym znajduj si pliki mediw prawdopodobnie uytych w Twoich wpisach.');
@define('FORCE_DELETE', 'Usu WSZYSTKIE pliki w tym katalogu, take te nie znane Serendipity i nie wywietlane w Bibliotece mediw');
@define('CREATE_DIRECTORY', 'Stwrz nowy katalog');
@define('CREATE_NEW_DIRECTORY', 'Stwrz nowy katalog');
@define('CREATE_DIRECTORY_DESC', 'Moesz tu stworzy nowy katalog, w ktrym bd przechowywane pliki mediw. Wpisz nazw nowego katalogu i wybierz ewentualny katalog nadrzdny, w ktrym zostanie utworzony Twj podkatalog.');
@define('BASE_DIRECTORY', 'Katalog bazowy');
@define('USERLEVEL_EDITOR_DESC', 'Standard editor');
@define('USERLEVEL_CHIEF_DESC', 'Chief editor');
@define('USERLEVEL_ADMIN_DESC', 'Administrator');
@define('USERCONF_USERLEVEL', 'Poziom dostpu');
@define('USERCONF_USERLEVEL_DESC', 'To ustawienie okrela jaki poziom dostpu ma uytkownik do bloga.');
@define('USER_SELF_INFO', 'Zalogowany(a) jako %s (%s)');
@define('ADMIN_ENTRIES', 'Wpisy');
@define('RECHECK_INSTALLATION', ' Sprawd ponownie instalacj');
@define('IMAGICK_EXEC_ERROR', 'Nie mona wykona: %s, bd: %s, zwrcona warto: %d');
@define('INSTALL_OFFSET_DESC', 'Podaj czas (w godzinach) przesunicia midzy czasem serwera (aktualny: %clock%) a Twoj stref czasow');
@define('UNMET_REQUIREMENTS', 'Niespenione wymagania: %s');
@define('CHARSET', 'Kodowanie');
@define('AUTOLANG', 'Uywaj ustawie jzyka przegladarki uytkownikw jako standardowych');
@define('AUTOLANG_DESC', 'Jeli ta opcja zostanie wczona, jzyk, w jakim bd wywietlane komunikaty i wpis bdzie zdeterminowany ustawienim jzyka przegldarki uytkownika odwiedzajcego Twojego bloga. Serendipity bdzie automatycznie dobierao wersj jzykow w zalenoci od ustwie przegldarki.');
@define('INSTALL_AUTODETECT_URL', 'Autodetect used HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', 'If set to "true", Serendipity will ensure that the HTTP Host which was used by your visitor is used as your BaseURL setting. Enabling this will let you be able to use multiple domain names for your Serendipity Blog, and use the domain for all follow-up links which the user used to access your blog.');
@define('CONVERT_HTMLENTITIES', 'Prbowa autokonwersji fragmentw HTML?');
@define('EMPTY_SETTING', 'Podano nieprawidowe dane dla "%s"!');
@define('USERCONF_REALNAME', 'Prawdziwe imi i nazwisko');
@define('USERCONF_REALNAME_DESC', 'Pene imi i nazwisko, jest widziane przez czytajcych');
@define('HOTLINK_DONE', 'Plik podlinkowany.<br />Zrobione.');
@define('ENTER_MEDIA_URL_METHOD', 'Sposb pobierania');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'UWAGA! Jeli wybierasz opcj linkowania do pliku w sieci, upewnij si, e masz do tego prawo! Linkowanie pozwala na uywanie obrazkw z innych stron bez potrzeby ich zgrywania na serwer.');
@define('MEDIA_HOTLINKED', 'podlinkowane');
@define('FETCH_METHOD_IMAGE', 'Pobierz obrazek na serwer');
@define('FETCH_METHOD_HOTLINK', 'Linkowanie do serwera');
@define('DELETE_HOTLINK_FILE', 'Skasuj podlinkowany plik o nazwie <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Pokazywa adresy e-mail?');
@define('IMAGE_MORE_INPUT', 'Dodaj wicej obrazkw');
@define('BACKEND_TITLE', 'Dodatkowe informacje na stonie Konfiguracja wtyczek');
@define('BACKEND_TITLE_FOR_NUGGET', 'Tu moesz poda dodatkowy opis, ktry bdzie wywietlany na stronie Konfiguracji Wtyczek razem z pluginem HTML Nugget. Przydatne kiedy posiadasz kilka takich HTMLowych wstawek, pozwala si jako w tym wszystkim poapa.');
@define('CATEGORIES_ALLOW_SELECT', 'Zezwoli uytkownikom na wywietlanie wielu kategorii jednoczenie?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Po wczeniu tej opcji przy kadej kategorii pojawi si pole umoliwiajce jej zaznaczenie. Uytkownicy mog zaznacza w ten sposb wiele kategorii jednoczenie i wywietla zbiorczo wpisy z tych zaznaczonych kategorii.');
@define('PAGE_BROWSE_PLUGINS', 'Strona %s z %s, cznie %s wtyczek.');
@define('INSTALL_CAT_PERMALINKS', 'Permalinks');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Defines various URL patterns to define permanent links in your blog. It is suggested that you use the defaults; if not, you should try to use the %id% value where possible to prevent Serendipity from querying the database to lookup the target URL.');
@define('INSTALL_PERMALINK', 'Permalink Entry URL structure');
@define('INSTALL_PERMALINK_DESC', 'Here you can define the relative URL structure beginning from your base URL to where entries may become available. You can use the variables %id%, %title%, %day%, %month%, %year% and any other characters.');
@define('INSTALL_PERMALINK_AUTHOR', 'Permalink Author URL structure');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Here you can define the relative URL structure beginning from your base URL to where entries from certain authors may become available. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
@define('INSTALL_PERMALINK_CATEGORY', 'Permalink Category URL structure');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Here you can define the relative URL structure beginning from your base URL to where entries from certain categories may become available. You can use the variables %id%, %name%, %description% and any other characters.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permalink RSS-Feed Category URL structure');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Here you can define the relative URL structure beginning from your base URL to where RSS-feeds from certain categories may become available. You can use the variables %id%, %name%, %description% and any other characters.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed Author URL structure');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Here you can define the relative URL structure beginning from your base URL to where RSS-feeds from specific users may be viewed. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Path to archives');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Path to archive');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Path to categories');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Path to authors');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Path to unsubscribe comments');
@define('INSTALL_PERMALINK_DELETEPATH', 'Path to delete comments');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Path to approve comments');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Path to RSS Feeds');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Path to single plugin');
@define('INSTALL_PERMALINK_ADMINPATH', 'Path to admin');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Path to search');
@define('USERCONF_CREATE', 'Zabro tworzenia wpisw?');
@define('USERCONF_CREATE_DESC', 'Jeli wybrane, uytkownik nie moe dokonywa nowych wpisw');
@define('INSTALL_CAL', 'Typ kalendarza');
@define('INSTALL_CAL_DESC', 'Wybierz swj typ kalendarza');
@define('REPLY', 'Odpowiedz');
@define('USERCONF_GROUPS', 'Przynaleno do grupy');
@define('USERCONF_GROUPS_DESC', 'Ten uytkownik naley do nastpujcych grup. Przynaleno do kilku grup jednoczenie jest moliwa.');
@define('MANAGE_GROUPS', 'Grupy');
@define('DELETED_GROUP', 'Grupa #%d %s usunita');
@define('CREATED_GROUP', 'Nowa grupa %s zostaa stworzona');
@define('MODIFIED_GROUP', 'Ustawienia grupy %s zostay zmienione');
@define('GROUP', 'Grupa');
@define('CREATE_NEW_GROUP', 'Stwrz now grup');
@define('DELETE_GROUP', 'Masz zamiar skasowa grup #%d %s. Na pewno?');
@define('USERLEVEL_OBSOLETE', 'UWAGA: to ustawienie jest obecnie uywane tylko dla celw kompatybilnoci ze starszymi wersjami wtyczek i silnika. Obecnie poziom dostpu reguluj reguy grup uytkownikw!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'ID (w serwisie FeedBurner) feeda, ktry chcesz publikowa');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner obrazek');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Nazwa pliku z obrazkiem, ktry bdzie wywietlany (obrazki s pobierane z serwera feedburner.com), np. fbapix.gif. Pozostaw puste by wywietli licznik (musisz wpierw uruchomi odpowiedni usug w serwisie FeedBurner!).');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner tytu');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Tytu (jeli jakikolwiek) jaki ma by wywietlany obok obrazka');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner tekst obrazka');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Tekst (jeli jakikolwiek) jaki ma by wywietlany po wskazniu kursorem obrazka');
@define('INSTALL_DBPORT', 'Port bazy danych');
@define('INSTALL_DBPORT_DESC', 'Port uywany do poczenia si z serwerem z Twoj baz danych');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Widoczne: Serwisy Zewntrzne');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Widoczne: Cechy/Ustawienia/Dodatki');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Widoczne: Pene Mody');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Widoczne: Przegldanie');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Widoczne: Zwizane z wpisem');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Niewidoczne: Edytor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Niewidoczne: Zarzdzanie uytkownikami');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Niewidoczne: Meta informacje');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Niewidoczne: Szablony');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Niewidoczne: Cechy/Ustawienia/Dodatki');
@define('PLUGIN_GROUP_IMAGES', 'Obrazki');
@define('PLUGIN_GROUP_ANTISPAM', 'Antyspam');
@define('PLUGIN_GROUP_MARKUP', 'Znaczniki');
@define('PLUGIN_GROUP_STATISTICS', 'Statystyki');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Dostp do ustawie osobistych');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Zmiana poziomu uytkownikw');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Zmiana "zabro tworzenia wpisw"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Zmiana uprawnie do publikowania wpisw');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Dostp do konfiguracji systemu');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Dostp do konfiguracji bloga');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administracja wpisami');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administracja wpisami innych uytkownikw');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Import wpisw');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administracja kategoriami');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administracja kategoriami innych uytkownikw');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Usuwanie kategorii');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administracja uytkownikami');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Usuwanie uytkownikw');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Zmiana poziomu uytkownikw');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administracja uytkownikami, ktrzy s w tej samej grupie (grupach)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administracja uytkownikami, ktrzy s w innych grupach');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Tworzenie nowych uytkownikw');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administracja grupami uytkownikw');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administracja wtyczkami');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administracja wtyczkami innych uytkownikw');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administracja mediami');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administracja katalogami mediw');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Dodawanie nowych mediw');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Usuwanie mediw');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administracja mediami innych uytkownikw');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Ogldanie plikw z mediami');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Synchronizacja miniatur');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administracja komentarzami');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administracja stylami');
@define('INSTALL_BLOG_EMAIL', 'Adres e-mail bloga');
@define('INSTALL_BLOG_EMAIL_DESC', 'Moesz tu wpisa adres poczty e-mail, ktry bdzie widoczny w polu "From" wysyanych maili z powiadomieniami. Upewnij si, e podajesz adres rozpoznawalny dla serwera - wiele serwerw mailowych odrzuca maile nie zawierajce poprawnego nagwka "From".');
@define('CATEGORIES_PARENT_BASE', 'Poka tylko kategorie zawierajce si w...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Moesz wybra kategori nadrzdn co spowoduje wywietlanie tylko kategorii podrzdnych, zawartych w kategorii nadrzdnej');
@define('CATEGORIES_HIDE_PARALLEL', 'Ukryj kategorie, ktre nie s czci drzewa kategorii');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Jeli chcesz ukry kategorie, ktre znajduj si w innym drzewie kategorii, musisz wczy t opcj. Korzystanie z tej opcji ma sens przy uywaniu Serendipity jako multi-bloga i uyciu wtyczki "Properties/Templates of categories".');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Ogldanie plikw z mediami innych uytkownikw');
@define('CHARSET_NATIVE', 'Natywne');
@define('INSTALL_CHARSET', 'Wybr kodowania znakw');
@define('INSTALL_CHARSET_DESC', 'Tu moesz ustawi kodowanie pomidzy UTF-8 a natywnym kodowaniem danego jzyka (ISO, EUC, ...). Niektre jzyki oferuj wsparcie tylko kodowania UTF-8 wic ich zmiana na "natywne" nie odniesie skutku. SUGERUJEMY wybr kodowania UTF-8 dla nowych instalacji. Nie zmieniaj tych ustawie jeli ju dokonae(a) wpisw ze znakami specjalnymi (diakrytycznymi) - to moe spowodowa problemy z wywietlaniem znakw. Przeczytaj wicej o tym problemie na stronie http://www.s9y.org/index.php?node=46');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Wcz odwoania wtyczek (API hook)');
@define('CALENDAR_EXTEVENT_DESC', 'Kiedy wczone, wtyczki mog tworzy odwoania do kalendarza by pokaza (podwietli) zdarzenia z nimi zwizane. Wcz to tylko gdy masz zainstalowane wtyczki korzystajce z opcji odwoania (hook), w przeciwnym wypadku tylko tracisz na wydajnoci wywietlania strony.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'Interfejs XML-RPC API nie jest ju wbudowany w Serendipity z powodu problemw z bezpieczestwem tego protokou. Jeli jednak chcesz obsug tego protokou mie zaimplementowan w swoim blogu, musisz zainstalowa wtyczk XML-RPC by mc uywa protokou XML-RPC API. URL, jaki naley uywa w swoich aplikacjach NIE ulegnie zmianie - kiedy tylko zainstalujesz wtyczk, bdziesz mg uywa tego API.');
@define('PERM_READ', 'Uprawnienia odczytu');
@define('PERM_WRITE', 'Uprawnienia zapisu');

@define('PERM_DENIED', 'Dostp zabroniony.');
@define('INSTALL_ACL', 'Zastosuj ograniczenia dostpu dla kategorii');
@define('INSTALL_ACL_DESC', 'Jeli to ustawienie zostanie wczone, bd stosowane ogranieczenia dostpu do kategorii podczas przegldania wpisw przez zalogowanych uytkownikw. Jeli ustawienie to zostanie wyczone, takie ogranieczenia NIE bd stosowane. Pozytywnym efektem wyczenia tej opcji jest przyspieszenie pracy silnika bloga. Jeli wic nie musisz stosowa ogranicze dostpu do kategorii - wycz t opcj.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Bdnie wprowadzone ustawienie dla opcji "%s". Ustwienie powinno by nastpujcego typu: "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Stare haso');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Jeli zmienisz haso w polu powyej, musisz w tym polu wpisa aktualne haso');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Wpisae(a) niepoprawne stare haso i nie jeste upowaniona do zmiany nowego hasa. Twoje ustawienia NIE zostan zapisane.');
@define('ERROR_XSRF', 'Your browser did not sent a valid HTTP-Referrer string. This may have either been caused by a misconfigured browser/proxy or by a Cross Site Request Forgery (XSRF) aimed at you. The action you requested could not be completed.');
@define('AUTHORS', 'Autorzy');
@define('AUTHORS_ALLOW_SELECT', 'Zezwoli uytkownikom na pokazywanie wpisw wielu autorw jednoczenie?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Jeli ta opcja zostanie wczona, obok kadego autora wywietlonego na Panelu Bocznym ukae si checkbox (pole zaznaczenia). Uytkownicy bd mogli zaznaczy autorw, ktrych wpisy bd chcieli wywietli.');
@define('AUTHOR_PLUGIN_DESC', 'Pokazuje list autorw');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Zezwoli na uywanie Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Wczenie tej opcji spowoduje uycie przez wtyczk moliwoci jakie oferuje Smarty do wywietlania drzewa kategorii. Po wczeniu tej opcji moesz wpywa na sposb wywietlania drzewa kategorii przez edycj pliku "plugin_categories.tpl". Wczenie tej opcji spowoduje spadek wydajnoci wic wcz j tylko kiedy jej na prawd potrzebujesz.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Informowa o iloci wpisw w danej kategorii?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Informowa o iloci wpisw dokonanych przez autora obok jego Imienia?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'jeli ta opcja zostanie wczona, obok autora zostanie pokazana ilo poczynionych przez niego wpisw ujeta w nawiasy.');
@define('CUSTOM_ADMIN_INTERFACE', 'Zmodyfikowany Panel Administracyjny dostpny');

@define('COMMENT_NOT_ADDED', 'Twj komentarz nie zosta dodany. Ewentualne przyczyny: moliwo komentowania zostaa wyczona lub wprowadzie(a) bdne dane lub Twj komentarz zosta uznany za spam.');
@define('INSTALL_TRACKREF', 'Enable referrer tracking?');
@define('INSTALL_TRACKREF_DESC', 'Enabling the referrer tracking will show you which sites refer to your articles. Today this is often abused for spamming, so you can disable it if you want.');
@define('CATEGORIES_HIDE_PARENT', 'Ukry wybran kategori nadrzdn?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Jeli ograniczysz wywietlanie kategorii do wybranej przez siebie kategorii nadrzdnej, standardowo zobaczysz nazw kategorii nadrzdnej. Wyczenie tej opcji (przez zaznaczenie pola "Tak") nie bdzie wywietlao nazwy tej kategorii nadrzdnej.');
@define('WARNING_NO_GROUPS_SELECTED', 'Uwaga: Nie dokonano przydziaw do adnej grupy. To spowoduje uniemoliwienie dministrowania przydziaami do grup. Twoje dotychczasowe przydziay nie zostay jednak zmienione. W przypadku problemw - skontaktuj si z administratorem.');
@define('INSTALL_RSSFETCHLIMIT', 'Ilo wpisw wywietlanych w feedach RSS');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Ilo wpisw wywietlanych na kadej stronie feeda RSS');
@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
@define('ONTHEFLYSYNCH', 'Wcz synchronizacj mediw "w locie"');
@define('ONTHEFLYSYNCH_DESC', 'Jeli wczone, Serendipity bdzie porwnywao zawarto bazy danych mediw z plikami istniejcymi na serwerze i w razie wystpienia rnic wykona synchronizacj bazy z zawartoci katalogw na serwerze.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'Pole nazwy uytkownika nie moe by puste.');
@define('FURTHER_LINKS', 'Przydatne linki');
@define('FURTHER_LINKS_S9Y', 'Strona domowa Serendipity');
@define('FURTHER_LINKS_S9Y_DOCS', 'Dokumentacja Serendipity');
@define('FURTHER_LINKS_S9Y_BLOG', 'Oficjalny blog Serendipity');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forum');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Komentarz usunity)');

@define('CURRENT_AUTHOR', 'Biecy Autor');

@define('WORD_NEW', 'Nowy');
@define('SHOW_MEDIA_TOOLBAR', 'Czy pokazywa pasek narzdziowy w oknie wyboru mediw?');
@define('MEDIA_KEYWORDS', 'Sowa kluczowe mediw');
@define('MEDIA_KEYWORDS_DESC', 'Wprowad predefiniowan list sw kluczowych dla mediw. Pozycje na licie rozdzielaj znakiem rednika ";". Te sowa kluczowe bd przypisywane mediom automatycznie przy importowaniu.');
@define('MEDIA_EXIF', 'Importuj dane EXIF/JPEG obrazkw/zdj');
@define('MEDIA_EXIF_DESC', 'Jeli opcja zostanie wczona, zapisane w plikach z obrazkami/zdjciami dane EXIF/JPEG zostan zachowane w bazie danych i wykorzystane przy wywietlaniu w Bibliotece mediw.');
@define('MEDIA_PROP', 'Waciwoci');


@define('GO_ADD_PROPERTIES', 'Dodaj i wprowad waciwoci');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Prawa autorskie (Copyright)');
@define('MEDIA_PROPERTY_COMMENT1', 'Krtki komentarz');
@define('MEDIA_PROPERTY_COMMENT2', 'Dugi komentarz');
@define('MEDIA_PROPERTY_TITLE', 'Tytu');
@define('MEDIA_PROP_DESC', 'Wprowad list pl waciwoci, jakie chcesz ustali dla kadego pliku medium. Elementy listy rozdzielaj znakiem rednika ";".');
@define('MEDIA_PROP_MULTIDESC', '(Moesz doda ":MULTI" po kadym elemencie by poinformowa Serendipity, e dany element bdzie posiada dugi opis)');

@define('STYLE_OPTIONS_NONE', 'Ten Styl nie posiada opcji specjalnych. Aby dowiedzie si jak moesz zaimplementowa w swoim Stylu opcje specjalne, odwied stron www.s9y.org i przeczytaj w dziale Technical Documentation dokument zatytuowany "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Opcje Stylu/Tematu');

@define('PLUGIN_AVAILABLE_COUNT', 'Razem: %d wtyczek');

@define('SYNDICATION_RFC2616', 'Aktywuj cise przestrzeganie standardu RFC2616 RSS-Feed');
@define('SYNDICATION_RFC2616_DESC', 'NIE przestrzeganie cise standardu RFC2616 oznacza, e wszelkie wywoania kanaw RSS zwrc wpisy, ktre ulegy zmianie od ostatniego takiego wywoania (np. przez czytnik RSS). Jeli ustawisz t opcj na Nie, subskrybenci Twoich kanaw RSS otrzymaj wszystkie artykuy od czasu ostatniego pobrania. To zasadniczo jest dobre i prawidowe zachowanie kanau RSS. Jednak niektrzy Agenci RSS, jak na przykad Planet, zachowuj si w takich sytuacjach dziwnie (np. co jaki czas pojawiaj si stare wpisy na stronach obsugiwanych przez Planet). Ustawenie tej opcji na Tak zaspokoi wymagania standardu, jednak czytelnikw Twoich kanaw RSS mog omin pewne wpisy, ktre po prostu nie bd ju pokazywane tym czytelnikom, nawet jeli jeszcze ich nie przeczytali. Ustawienie tej opcji moe by wic problemem albo dla Agregatorw typu Planet, albo dla Twoich czytelnikw. Wicej informacji: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
@define('MEDIA_PROPERTY_DATE', 'Data');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Czas trwania');
@define('FILENAME_REASSIGNED', 'Automatycznie przydzielona nowa nazwa pliku: %s');
@define('MEDIA_UPLOAD_SIZE', 'Maksymalny rozmiar wysyanego pliku');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Wprowad maksymalny rozmiar wysyanego pliku w bajtach. To ustawienie moe by uniewanione przez ustawienia serwera w pliku PHP.ini: upload_max_filesize, post_max_size, max_input_time - wszystkie te opcje mog mie wpyw na to ustawienie. Puste pole oznacza, e maj by stosowane ustawienia po stronie serwera.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Bd: Nie moesz wysya na serwer plikw wikszych ni %s bajtw!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Maksymalna szeroko obrazkw wysyanych na serwer');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Wprowad maksymaln szeroko (w pikselach) dla wysyanych na serwer obrazkw');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Maksymlana wysoko obrazkw wysyanych na serwer');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Wprowad maksymaln wysoko (w pikselach) dla wysyanych na serwer obrazkw');
@define('MEDIA_UPLOAD_DIMERROR', 'Bd: Nie moesz wysya na serwer obrazkw wikszych ni %s x %s piksele!');

@define('MEDIA_TARGET', 'Sposb wywietlenia');
@define('MEDIA_TARGET_JS', 'Okienko Popup (via JavaScript, rozmiar dopasowujcy si do obrazka)');
@define('MEDIA_ENTRY', 'Osobny wpis');
@define('MEDIA_TARGET_BLANK', 'Osobne okno (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Zezwala na dynamiczn zmian rozmiaru?');
@define('MEDIA_DYN_RESIZE_DESC', 'Jeli wczone, modu obsugi mediw moe zwracac obrazki w dowolnej danej wielkoci podawanej przez GET. Rezultaty zmian s buforowane i mog spowodowa spory rozrost bazy plikw jeli bdzie ta opcja wykorzystywana intensywnie.');

@define('MEDIA_DIRECTORY_MOVED', 'Katalog i pliki zostay poprawnie przeniesione do %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Katalog i pliki nie mogy by przeniesione do %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'W bazach innych ni MySQL przeprowadzenie zmiany URLI ze sciek do starego katalogu na URLe ze ciek do nowego katalogu NIE jest moliwe. Musisz przeprowadzi te zmiany rcznie. Zawsze moesz przenie katalog w jego pierwotne miejsce jeli uznasz, e rczna edycja byaby zbyt nieporcznym rozwizaniem.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Zmieniono URL do przeniesionego katalogu w %s wpisach.');
@define('PLUGIN_ACTIVE', 'Wtyczki aktywne');
@define('PLUGIN_INACTIVE', 'Wtyczki nieaktywne');
@define('PREFERENCE_USE_JS', 'Zezwoli na uywanie zaawansowanych skryptw JavaScript?');
@define('PREFERENCE_USE_JS_DESC', 'Jeli wczone, zaawansowane skrypty JavaScript bd uruchamiane dla zwikszenia komfortu uywalnoci, np. w module Konfiguracji wtyczek moesz administarowa wtyczkami za pomoc myszy przez ich swobodne przesuwanie jak w technologii "drag and drop" (przecignij i upu).');

@define('PREFERENCE_USE_JS_WARNING', '(Ta strona uywa zaawansowanych skryptw JavaScript. Jeli masz problemy z funkcjonowaniem tej strony, wycz uywanie zaawansowanych skryptw JavaScript w swoich Ustawieniach osobistych lub wycz wspracie dla JavaScript w swojej przegldarce.)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
